from django.db import models # type: ignore

class MaintenanceMode(models.Model):
    is_active = models.BooleanField(default=False)
    message = models.TextField(default="The site is under maintenance.")

    def __str__(self):
        return "ON" if self.is_active else "OFF"


from django.http import HttpResponse, JsonResponse # type: ignore
from .models import MaintenanceMode

class DynamicMaintenanceMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        try:
            if request.path.startswith("/admin") or request.path.startswith("/api/admin"):
                return self.get_response(request)

            mode = MaintenanceMode.objects.first()
            if mode and mode.is_active:
                if request.user.is_authenticated and request.user.is_superuser:
                    return self.get_response(request)

                if request.path.startswith('/api') or 'application/json' in request.headers.get('Accept', ''):
                    return JsonResponse(
                        {"detail": "Service unavailable due to maintenance."},
                        status=503
                    )
                else:
                    return HttpResponse(
                        f"<h1>Maintenance Mode</h1><p>{mode.message}</p>",
                        content_type="text/html",
                        status=503
                    )
        except Exception:
            pass

        return self.get_response(request)


import pathlib
from setuptools import setup, find_packages # type: ignore

# Get the long description from README.md
HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text(encoding="utf-8")

setup(
    name='django-dynamic-maintenance-mode',
    version='0.1.0',
    description='Django middleware to enable maintenance mode dynamically using a database flag.',
    long_description=README,
    long_description_content_type='text/markdown',
    author='Pranav Dixit',
    author_email='pranavdixit20@gmail.com',
    url='https://github.com/pranav-dixit/django-dynamic-maintenance-mode',
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
    install_requires=[
        'Django>=3.2',
    ],
    entry_points={
        'console_scripts': [
            # Optional: future CLI commands
        ],
    },
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 4.1',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
    python_requires='>=3.7',
)